function xM = SysWinterhalder05m1(n)
% xM = SysWinterhalder05m1(n)
% SysWinterhalder05m1 generates a multivariate linear time series of 4 
% variables from a VAR(5) model. The causality relationships are as
% follows, where the number in parenthesis stands for the largest lag of
% the driving variable in the expression for the response variable.
% x1(1)-->x3  
% x2(4)-->x1  x2(4)-->x3
% x4(5)-->x2
% INPUTS
% - n   : the time series length
% OUTPUTS
% - xM  : the n x 4 matrix of the generated time series
% 
% Reference: 
% Winterhalder et al.
% Comparison of linear signal processing techniques to
% infer directed interactions in multivariate neural systems. 
% Signal Processing 85:21372160, 2005.
% Example Model 1: Four-dimensional vector autoregressive process
%
%     Copyright (C) 2015 Dimitris Kugiumtzis
%
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
%
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
%
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
ntrans = 100;
K = 4; % number of variables
P = 5; % order of VAR
wM = randn(n+ntrans,K);
xM = NaN*ones(n+ntrans,K);
xM(1:P,:) = wM(1:P,:);
for t=P+1:n+ntrans
    xM(t,1)=0.8*xM(t-1,1)+0.65*xM(t-4,2)+wM(t,1);
    xM(t,2)=0.6*xM(t-1,2)+0.6*xM(t-5,4)+wM(t,2);
    xM(t,3)=0.5*xM(t-3,3)-0.6*xM(t-1,1)+0.4*xM(t-4,2)+wM(t,3);
    xM(t,4)=1.2*xM(t-1,4)-0.7*xM(t-2,4)+wM(t,4);
end;
xM = xM(ntrans+1:n+ntrans,:);
